@@ -45,8 +45,7 @@ void PlacesItemSignalHandler::onTearDownRequested(const QString& udi)
     if (m_item) {
         Solid::StorageAccess *tmp = m_item->device().as<Solid::StorageAccess>();
         if (tmp) {
-            QString mountPath = tmp->filePath();
-            emit tearDownExternallyRequested(mountPath);
+            emit tearDownExternallyRequested(tmp->filePath());
         }
     }
 }
